@@ -15,15 +15,18 @@ Installer.install()
 
 from pacifico.util import Output, Format, Enumerations, Arguments, Downloader
 from pacifico.core.Service.ServiceRequest.ServiceRequestDataPoint import ServiceRequestDataPointValue, ServiceRequestDataPointReport
+from pacifico.core.Service.ServiceRequest.ServiceRequestApplication import ServiceRequestApplication
 import datetime
 import sys
 
-def request(token='', ticker='', family='', group='', market='', country=Enumerations.Country.Country_Unspecified,
+def request(token='', ticker='', family='', group='', market='', country='',
             document='', item='', chapter='', section='', subsection='', paragraph='', app='', help=False,
             dateStart=datetime.datetime.today().date(), dateEnd=datetime.datetime.today().date(),
             fixing=Enumerations.Fixing.EOD, fieldType='', versionType=Enumerations.VersionType.Version_Unspecified,
             author='', version='', quality=Enumerations.Quality.Quality_Unspecified, timeOut=300, timeFrecuency=0.5,
             fileName='', format='dataFrame', **kwargs):
+    if country == '':
+        country = Enumerations.Country.Country_Unspecified
     if app != '':
         return requestApplication(token, app, help, timeOut, timeFrecuency, fileName, format, **kwargs, ticker=ticker,
                                   family=family, group=group, market=market, country=country, document=document,
